@@ -1,7 +1,9 @@
 from .read import read
 from .write import write
+from .text.text_reader import json_data
 
 __all__ = [
     "read",
-    "write"
+    "write",
+    "json_data"
 ]
