@@ -2,7 +2,7 @@ from .dense import DenseBlock
 from .inception import InceptionModule
 from .mlp import MLP
 from .residual import ResidualModule, ResidualBlock
-from .transformer import TransformerEncoderBlock, AttentionModule, TransformerEncoder
+from .transformer import TransformerEncoderBlock, TransformerEncoder
 
 __all__ = [
     "DenseBlock",
@@ -10,6 +10,5 @@ __all__ = [
     "MLP",
     "ResidualBlock",
     "ResidualModule",
-    "TransformerEncoderBlock",
-    "AttentionModule"
+    "TransformerEncoderBlock"
 ]
