@@ -1,8 +1,10 @@
 from typing import Tuple, Union
 
+import numpy as np
 import torch
-from cleanfid.resize import make_resizer
+from PIL import Image
 from einops import rearrange
+from numpy import ndarray
 from torch import Tensor, uint8, float32
 from torch.nn import functional as func
 
@@ -10,10 +12,10 @@ from .enum import ResizeMethod, get_enum_value
 from ..util import F, _
 
 
-def resize_image(tensor: Tensor, size: Tuple[int, int], resize_method: Union[ResizeMethod, str] = ResizeMethod.BICUBIC
+def resize_image(tensor: Tensor, size: Tuple[int, int], resize_method: ResizeMethod = ResizeMethod.BICUBIC
 ) -> Tensor:
     """
-    Resizing a image to determined size.
+    Resizing an image to determined size.
 
     Args:
         tensor (:class:`~torch.Tensor`): Image tensor (C, H, W)
@@ -24,9 +26,13 @@ def resize_image(tensor: Tensor, size: Tuple[int, int], resize_method: Union[Res
         :class:`~torch.Tensor`: The resized image.
     """
     h, w = size
-    resize_method = get_enum_value(resize_method, ResizeMethod)
 
-    resizer = make_resizer("PIL", True, resize_method, (w, h))
+    def resizer(x: ndarray) -> ndarray:
+        x = Image.fromarray(x)
+        x = x.resize((w, h), resample=resize_method.value)
+        x = np.asarray(x).astype(np.uint8)
+        return x
+
     f = F(rearrange, pattern="c h w -> h w c") \
         >> _ * 255 \
         >> (lambda x: x.to(uint8).numpy()) \
@@ -38,7 +44,7 @@ def resize_image(tensor: Tensor, size: Tuple[int, int], resize_method: Union[Res
     return f(tensor)
 
 
-def resize_video(tensor: Tensor, size: Tuple[int, int], resize_method: Union[ResizeMethod, str] = ResizeMethod.BICUBIC,
+def resize_video(tensor: Tensor, size: Tuple[int, int], resize_method: ResizeMethod = ResizeMethod.BICUBIC,
     fast=False
 ) -> Tensor:
     """
@@ -54,7 +60,6 @@ def resize_video(tensor: Tensor, size: Tuple[int, int], resize_method: Union[Res
         :class:`~torch.Tensor`: The resized video.
     """
     if not fast:
-        resize_method = get_enum_value(resize_method, ResizeMethod)
         image_resizer = F(resize_image, size=size, resize_method=resize_method) \
                         >> F(rearrange, pattern="c h w -> 1 c h w")
         f = F(map, image_resizer) \
