@@ -1,13 +1,13 @@
 from einops.layers.torch import Rearrange as _Rearrange
 
-from tensorneko_util.util import AbstractServer, dispatch, AverageMeter
+from tensorneko_util.util import AbstractServer, dispatch, AverageMeter, tensorneko_util_path
 from tensorneko_util.util.fp import Seq, AbstractSeq, curry, Some, Empty, F, Stream, return_option, Option, _, __
+from tensorneko_util.util import ref
 from . import type
 from .configuration import Configuration
 from .func import reduce_dict_by, summarize_dict_by, with_printed_shape, is_bad_num, count_parameters, compose, \
     generate_inf_seq, listdir, with_printed, ifelse, dict_add, as_list, identity, list_to_dict
 from .func import get_tensorneko_path
-from .ref import ref
 from .reproducibility import Seed
 from .string_getter import get_activation, get_loss
 from .type import ModuleFactory, Shape, Device
@@ -15,6 +15,7 @@ from .type import ModuleFactory, Shape, Device
 Rearrange = _Rearrange
 
 tensorneko_path = get_tensorneko_path()
+tensorneko_util_path = tensorneko_util_path
 
 __all__ = [
     "reduce_dict_by",
@@ -50,6 +51,7 @@ __all__ = [
     "_",
     "F",
     "tensorneko_path",
+    "tensorneko_util_path",
     "AbstractServer",
     "dispatch",
     "AverageMeter",
